==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/sr.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Галерија",
    "There was a problem reading files from this album" : "Проблем приликом читања фајлова из овог албума",
    "Aborting preview. Could not find the file" : "Прекидам преглед. Не могу пронаћи датотеку",
    "Could not move \"{file}\", target exists" : "Не могу да померим \"{file}\", одредиште већ постоји",
    "Could not move \"{file}\"" : "Не могу да померим \"{file}\"",
    "No compatible server found at {remote}" : "Нема компатибилног сервера на {remote}",
    "Invalid server url" : "Неисправна адреса сервера",
    "Could not load the description" : "Не могу да учитам опис",
    "Could not load the description: " : "Не могу да учитам опис:",
    "Copyright" : "Ауторско право",
    "Could not load the copyright notice: " : "Не могу да учитам белешку о заштићеном ауторском праву",
    "Copyright notice" : "Белешка о заштићеном ауторском праву",
    "Link to copyright document" : "Веза ка документу ауторског права",
    "This application may not work properly on your browser." : "Ова апликација може да не ради исправно на вашем веб читачу.",
    "For an improved experience, please install one of the following alternatives" : "За боље искуство, инсталирајте један од следећих алтернатива",
    "Your browser is not supported!" : "Ваш веб читач није подржан!",
    "please install one of the following alternatives" : "инсталирајте један од следећих алтернатива",
    "Album cannot be shown" : "Албум се не може приказати",
    "No media files found" : "Нема мултимедијалних фајлова",
    "Upload pictures in the Files app to display them here" : "Отпремите слике у апликацију \"Фајлови\" да бисте их приказали овде",
    "Upload new files via drag and drop or by using the [+] button above" : "Отпремите нове фајлове превлачећи их или користећи [+] дугме изнад ",
    "Configuration error" : "Грешка подешавања",
    "New" : "Ново",
    "Hide Album" : "Сакриј албум",
    "Could not hide album" : "Не могу да сакријем албум",
    "Error loading slideshow template" : "Грешка при учитавању шаблона за слајдове",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Грешка!</strong> Не могу да направим претпреглед овог фајла. <br>Идите на следећи слајд док ми избацујемо ову слику из слајд-шоа",
    "Next" : "Следеће",
    "Play" : "Пусти",
    "Pause" : "Паузирај",
    "Previous" : "Претходна",
    "Close" : "Затвори",
    "Download" : "Преузми",
    "Toggle background" : "Укључи/искључи позадину",
    "Delete" : "Обриши",
    "Share" : "Подели",
    "Could not create file \"{file}\" because it already exists" : "Не могу да направим фајл \"{file}\" јер већ постоји",
    "Could not create file \"{file}\"" : "Не могу да направим фајл \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" није исправан назив фајла.",
    "File name cannot be empty." : "Назив фајла не може бити празан.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" није дозвољени тип фајла",
    "Upload" : "Отпреми",
    "Error" : "Грешка",
    "Error while sharing" : "Грешка при дељењу",
    "Error while unsharing" : "Грешка при укидању дељења",
    "Error while changing permissions" : "Грешка при измени дозвола",
    "Shared with you and the group {group} by {owner}" : "{owner} дели са Вама и са групом {group}.",
    "Shared with you by {owner}" : "{owner} дели са Вама",
    "Share with users or groups …" : "Дели са корисницима или групама …",
    "Share with users, groups or remote users …" : "Дели са корисницима, групама или удаљеним корисницима …",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Поделите са људима у другим облацима користећи ID њиховог здруженог облика, као username@example.com/cloud",
    "Share link" : "Веза дељења",
    "The public link will expire no later than {days} days after it is created" : "Јавна веза ће престати да важи {days} дана након стварања",
    "Link" : "Веза",
    "Password protect" : "Заштићено лозинком",
    "Password" : "Лозинка",
    "Choose a password for the public link" : "Одредите лозинку за јавну везу",
    "Allow editing" : "Дозволи уређивање",
    "Email link to person" : "Пошаљи е-поштом",
    "Send" : "Пошаљи",
    "Set expiration date" : "Постави датум истека",
    "Expiration" : "Истиче",
    "Expiration date" : "Датум истека",
    "This list is maybe truncated - please refine your search term to see more results." : "Ова листа је можда скраћена - претражите опет користећи мало специфичније изразе да бисте добили још резултата.",
    "No users or groups found for {search}" : "Није нађен ниједан корисник ни група за претрагу {search}",
    "No users found for {search}" : "Није нађен ниједан корисник за претрагу {search}",
    "An error occured. Please try again" : "Дошло је до грешке. Покушајте поново",
    "Adding user..." : "Додајем корисника...",
    "group" : "група",
    "remote" : "удаљени",
    "Resharing is not allowed" : "Поновно дељење није дозвољено",
    "Error while retrieving shares" : "Грешка при дохватању дељења",
    "Unshare" : "Не дели",
    "notify by email" : "обавести е-поштом",
    "can share" : "може да дели",
    "can edit" : "може да мења",
    "access control" : "права приступа",
    "create" : "направи",
    "change" : "измени",
    "delete" : "обриши",
    "Password protected" : "Заштићено лозинком",
    "Error unsetting expiration date" : "Грешка при поништавању датума истека",
    "Error setting expiration date" : "Грешка при постављању датума истека",
    "Sending ..." : "Шаљем ...",
    "Email sent" : "Порука је послата",
    "Warning" : "Упозорење",
    "This share is password-protected" : "Дељење је заштићено лозинком",
    "The password is wrong. Try again." : "Лозинка је погрешна. Покушајте поново.",
    "Sort by name" : "Сортирај по имену",
    "Sort by date" : "Сортирај по датуму",
    "Cancel upload" : "Откажи отпремање",
    "Album information" : "Информације о албуму",
    "File list" : "Списак фајлова",
    "Sorry, this file could not be found." : "Жао нам је, али овај фајл не може да се нађе.",
    "Reasons might be:" : "Разлози могу бити:",
    "the wrong file ID was provided" : "дата је погрешна идентификација фајла",
    "the file was removed" : "фајл је уклоњен",
    "the file is corrupt" : "фајл је оштећен",
    "the encryption key is missing" : "недостаје кључ за шифру",
    "Here is the error message returned by the server: " : "Ово је поруке о грешци са сервера:",
    "For more information, please contact your friendly Nextcloud administrator." : "За више информација, контактирајте Вашег пријатељски настројеног Некстклауд администратора",
    "Sorry, but the server could not fulfill your request." : "Жао нам је, али сервер није могао да обради Ваш захтев.",
    "Possible reasons for the problem:" : "Могући разлози за овај проблем су:",
    "a conflicting app was installed" : "већ је инсталирана неусаглашена апликација",
    "a required component is missing or was disconnected" : "захтевана компонента недостаје или је откачена",
    "the filesystem is not readable" : "систем фајлова не може да се чита",
    "Sorry, this link doesn't seem to work anymore." : "Нажалост, изгледа да веза више не ради. ",
    "the item was removed" : "ставка је уклоњена",
    "the link has expired" : "веза је истекла",
    "sharing is disabled" : "дељење је искључено",
    "For more information, please ask the person who has sent you this link." : "За више информација, питајте особу која вам је послала везу.",
    "Add to your Nextcloud" : "Додај у свој облак",
    "Picture view" : "Приказ слике",
    "Gallery view" : "Приказ галерије"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/sr.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Галерија",
    "There was a problem reading files from this album" : "Проблем приликом читања фајлова из овог албума",
    "Aborting preview. Could not find the file" : "Прекидам преглед. Не могу пронаћи датотеку",
    "Could not move \"{file}\", target exists" : "Не могу да померим \"{file}\", одредиште већ постоји",
    "Could not move \"{file}\"" : "Не могу да померим \"{file}\"",
    "No compatible server found at {remote}" : "Нема компатибилног сервера на {remote}",
    "Invalid server url" : "Неисправна адреса сервера",
    "Could not load the description" : "Не могу да учитам опис",
    "Could not load the description: " : "Не могу да учитам опис:",
    "Copyright" : "Ауторско право",
    "Could not load the copyright notice: " : "Не могу да учитам белешку о заштићеном ауторском праву",
    "Copyright notice" : "Белешка о заштићеном ауторском праву",
    "Link to copyright document" : "Веза ка документу ауторског права",
    "This application may not work properly on your browser." : "Ова апликација може да не ради исправно на вашем веб читачу.",
    "For an improved experience, please install one of the following alternatives" : "За боље искуство, инсталирајте један од следећих алтернатива",
    "Your browser is not supported!" : "Ваш веб читач није подржан!",
    "please install one of the following alternatives" : "инсталирајте један од следећих алтернатива",
    "Album cannot be shown" : "Албум се не може приказати",
    "No media files found" : "Нема мултимедијалних фајлова",
    "Upload pictures in the Files app to display them here" : "Отпремите слике у апликацију \"Фајлови\" да бисте их приказали овде",
    "Upload new files via drag and drop or by using the [+] button above" : "Отпремите нове фајлове превлачећи их или користећи [+] дугме изнад ",
    "Configuration error" : "Грешка подешавања",
    "New" : "Ново",
    "Hide Album" : "Сакриј албум",
    "Could not hide album" : "Не могу да сакријем албум",
    "Error loading slideshow template" : "Грешка при учитавању шаблона за слајдове",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Грешка!</strong> Не могу да направим претпреглед овог фајла. <br>Идите на следећи слајд док ми избацујемо ову слику из слајд-шоа",
    "Next" : "Следеће",
    "Play" : "Пусти",
    "Pause" : "Паузирај",
    "Previous" : "Претходна",
    "Close" : "Затвори",
    "Download" : "Преузми",
    "Toggle background" : "Укључи/искључи позадину",
    "Delete" : "Обриши",
    "Share" : "Подели",
    "Could not create file \"{file}\" because it already exists" : "Не могу да направим фајл \"{file}\" јер већ постоји",
    "Could not create file \"{file}\"" : "Не могу да направим фајл \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" није исправан назив фајла.",
    "File name cannot be empty." : "Назив фајла не може бити празан.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" није дозвољени тип фајла",
    "Upload" : "Отпреми",
    "Error" : "Грешка",
    "Error while sharing" : "Грешка при дељењу",
    "Error while unsharing" : "Грешка при укидању дељења",
    "Error while changing permissions" : "Грешка при измени дозвола",
    "Shared with you and the group {group} by {owner}" : "{owner} дели са Вама и са групом {group}.",
    "Shared with you by {owner}" : "{owner} дели са Вама",
    "Share with users or groups …" : "Дели са корисницима или групама …",
    "Share with users, groups or remote users …" : "Дели са корисницима, групама или удаљеним корисницима …",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Поделите са људима у другим облацима користећи ID њиховог здруженог облика, као username@example.com/cloud",
    "Share link" : "Веза дељења",
    "The public link will expire no later than {days} days after it is created" : "Јавна веза ће престати да важи {days} дана након стварања",
    "Link" : "Веза",
    "Password protect" : "Заштићено лозинком",
    "Password" : "Лозинка",
    "Choose a password for the public link" : "Одредите лозинку за јавну везу",
    "Allow editing" : "Дозволи уређивање",
    "Email link to person" : "Пошаљи е-поштом",
    "Send" : "Пошаљи",
    "Set expiration date" : "Постави датум истека",
    "Expiration" : "Истиче",
    "Expiration date" : "Датум истека",
    "This list is maybe truncated - please refine your search term to see more results." : "Ова листа је можда скраћена - претражите опет користећи мало специфичније изразе да бисте добили још резултата.",
    "No users or groups found for {search}" : "Није нађен ниједан корисник ни група за претрагу {search}",
    "No users found for {search}" : "Није нађен ниједан корисник за претрагу {search}",
    "An error occured. Please try again" : "Дошло је до грешке. Покушајте поново",
    "Adding user..." : "Додајем корисника...",
    "group" : "група",
    "remote" : "удаљени",
    "Resharing is not allowed" : "Поновно дељење није дозвољено",
    "Error while retrieving shares" : "Грешка при дохватању дељења",
    "Unshare" : "Не дели",
    "notify by email" : "обавести е-поштом",
    "can share" : "може да дели",
    "can edit" : "може да мења",
    "access control" : "права приступа",
    "create" : "направи",
    "change" : "измени",
    "delete" : "обриши",
    "Password protected" : "Заштићено лозинком",
    "Error unsetting expiration date" : "Грешка при поништавању датума истека",
    "Error setting expiration date" : "Грешка при постављању датума истека",
    "Email sent" : "Порука је послата",
    "Warning" : "Упозорење",
    "This share is password-protected" : "Дељење је заштићено лозинком",
    "The password is wrong. Try again." : "Лозинка је погрешна. Покушајте поново.",
    "Sort by name" : "Сортирај по имену",
    "Sort by date" : "Сортирај по датуму",
    "Cancel upload" : "Откажи отпремање",
    "Album information" : "Информације о албуму",
    "File list" : "Списак фајлова",
    "Sorry, this file could not be found." : "Жао нам је, али овај фајл не може да се нађе.",
    "Reasons might be:" : "Разлози могу бити:",
    "the wrong file ID was provided" : "дата је погрешна идентификација фајла",
    "the file was removed" : "фајл је уклоњен",
    "the file is corrupt" : "фајл је оштећен",
    "the encryption key is missing" : "недостаје кључ за шифру",
    "Here is the error message returned by the server: " : "Ово је поруке о грешци са сервера:",
    "For more information, please contact your friendly Nextcloud administrator." : "За више информација, контактирајте Вашег пријатељски настројеног Некстклауд администратора",
    "Sorry, but the server could not fulfill your request." : "Жао нам је, али сервер није могао да обради Ваш захтев.",
    "Possible reasons for the problem:" : "Могући разлози за овај проблем су:",
    "a conflicting app was installed" : "већ је инсталирана неусаглашена апликација",
    "a required component is missing or was disconnected" : "захтевана компонента недостаје или је откачена",
    "the filesystem is not readable" : "систем фајлова не може да се чита",
    "Sorry, this link doesn't seem to work anymore." : "Нажалост, изгледа да веза више не ради. ",
    "the item was removed" : "ставка је уклоњена",
    "the link has expired" : "веза је истекла",
    "sharing is disabled" : "дељење је искључено",
    "For more information, please ask the person who has sent you this link." : "За више информација, питајте особу која вам је послала везу.",
    "Add to your Nextcloud" : "Додај у свој облак",
    "Picture view" : "Приказ слике",
    "Gallery view" : "Приказ галерије",
    "Sending ..." : "Шаљем ..."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
